<?php
/*
Plugin Name: Default Values For Attachments
Plugin URI: http://plugins.moraleida.me/default-values
Description: Set default Title, Caption or Description for every image you upload.
Version: 0.2
Author: Ricardo Moraleida
Author URI: http://moraleida.me
License: GPLv2
Text Domain: me_dvfa_locale
*/

/*  Copyright 2012  Ricardo Moraleida  (email : ricardo [at] moraleida.me)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// Proper localization
function me_dvfa_locale_init() {
    load_plugin_textdomain('me_dvfa_locale', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action('plugins_loaded', 'me_dvfa_locale_init');



// Create the Media Menu
function me_dvfa_media_menu_page() {
    add_media_page('Default Values', __('Default Values', 'me_dvfa_locale'), 'activate_plugins', 'me_dvfa_default_values', 'me_dfva_options');
}
add_action('admin_menu', 'me_dvfa_media_menu_page');

// Main options page
function me_dfva_options() {
    
    $upload_dir = wp_upload_dir();
    
    $nonce = wp_create_nonce  ('me_dvfa_nonce_');
    
    
    $title = 'me_dvfa_default_attachment_title';
    $caption = 'me_dvfa_default_attachment_caption';
    $description = 'me_dvfa_default_attachment_description';
    $alttext = 'me_dvfa_default_attachment_alt_text';
    
    // Grab defaults from the DB
    $title_val = get_option($title);
    $caption_val = get_option($caption);
    $description_val = get_option($description);
    $alttext_val = get_option($alttext);
    
    // Are we saving anything yet?
    if ($_POST['default_type'] == 'me_dvfa_defaults') :
        
        if (! wp_verify_nonce($nonce, 'me_dvfa_nonce_') ) die('Security check'); 
        
        // If so, get the inputs
        $title_val = $_POST[$title];
        $caption_val = $_POST[$caption];
        $description_val = $_POST[$description];
        $alttext_val = $_POST[$alttext];
        
        // And update their values to the DB
        update_option($title, $title_val);
        update_option($caption, $caption_val);
        update_option($description, $description_val);
        update_option($alttext, $alttext_val);

        print '<div class="updated"><p><strong>'. __("your-uploaded-file-name.jpg","me_dvfa_locale").'</strong></p></div>';
    endif;
    
?>
    <div class="wrap">
    <h2><?php  _e('Set Default Media Values','me_dvfa_locale'); ?></h2>
    <p><?php  _e('Use the form below to set default values for every media item you upload on this site. Any field left blank on the upload process will be replaced by the corresponding values below.','me_dvfa_locale'); ?></p>
    <form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" class="media-upload-form" id="me_dfva_default_values">
    <p class="submit" style="padding-bottom: 0;">
    <input type="submit" name="save" id="save" class="button-primary" value="<?php  _e('Save Default Values','me_dvfa_locale'); ?>"  /></p>
        <div class="media-single">
        <div id='default_media_item' class='media-item'>
                <input type='hidden' name='default_type' value='me_dvfa_defaults' />
                
	<table class='slidetoggle describe '>
		<thead class='media-item-info' id='default_media_head'>
		<tr valign='top'>
			<td class='A1B1' id='default_thumbnail-head'>
			<p><img class='thumbnail' src='<?php echo plugins_url('me_dvfa_image.jpg', __FILE__); ?>' alt='' /></p>
			</td>
			<td>
			<p><strong><?php  _e('File name:',"me_dvfa_locale"); ?></strong><?php  _e('your-uploaded-file-name.jpg','me_dvfa_locale'); ?></p>
			<p><strong><?php  _e('File type:',"me_dvfa_locale"); ?></strong> image/jpeg</p>
			<p><strong><?php  _e('Upload date:',"me_dvfa_locale"); ?></strong><?php echo date(' d/m/Y'); ?></p><p><strong><?php  _e('Dimensions:',"me_dvfa_locale"); ?></strong> <span id='media-dims-15'>1024&nbsp;&times;&nbsp;768</span> </p>
                        </td>
                </tr>
		</thead>
		<tbody>
		<tr><td colspan='2' class='imgedit-response' id='imgedit-response-15'></td></tr>
		<tr><td style='display:none' colspan='2' class='image-editor' id='image-editor-15'></td></tr>
		<tr class='post_title form-required'>
			<th valign='top' scope='row' class='label'><label for='me_dvfa_default_attachment_title'><span class='alignleft'><?php  _e('Title',"me_dvfa_locale"); ?></span><span class="alignright"><abbr title="required" class="required">*</abbr></span><br class='clear' /></label></th>
			<td class='field'><input type='text' class='text' id='me_dvfa_default_attachment_title' name='me_dvfa_default_attachment_title' value='<?php echo $title_val; ?>'  aria-required='true'  /></td>
		</tr>
		<tr class='image_alt'>
			<th valign='top' scope='row' class='label'><label for='me_dvfa_default_attachment_alt_text'><span class='alignleft'><?php  _e('Alternate Text',"me_dvfa_locale"); ?></span><br class='clear' /></label></th>
			<td class='field'><input type='text' class='text' readonly='readonly' id='me_dvfa_default_attachment_alt_text' name='me_dvfa_default_attachment_alt_text' value=''  /><p class='help'><?php  _e('Alt text for the image, e.g. &#8220;The Mona Lisa&#8221;',"me_dvfa_locale"); ?></p></td>
		</tr>
		<tr class='post_excerpt'>
			<th valign='top' scope='row' class='label'><label for='me_dvfa_default_attachment_caption'><span class='alignleft'><?php  _e('Caption',"me_dvfa_locale"); ?></span><br class='clear' /></label></th>
			<td class='field'><input type='text' class='text' id='me_dvfa_default_attachment_caption' name='me_dvfa_default_attachment_caption' value='<?php echo $caption_val; ?>'  /></td>
		</tr>
		<tr class='post_content'>
			<th valign='top' scope='row' class='label'><label for='me_dvfa_default_attachment_description'><span class='alignleft'><?php  _e('Description',"me_dvfa_locale"); ?></span><br class='clear' /></label></th>
			<td class='field'><textarea id='me_dvfa_default_attachment_description' name='me_dvfa_default_attachment_description' ><?php echo $description_val; ?></textarea></td>
		</tr>
		<tr class='image_url'>
			<th valign='top' scope='row' class='label'><label for='me_dvfa_default_attachment_url'><span class='alignleft'><?php  _e('File URL',"me_dvfa_locale"); ?></span><br class='clear' /></label></th>
			<td class='field'><input type='text' class='text urlfield' readonly='readonly' name='attachments[15][url]' value='<?php echo $upload_dir['baseurl']; ?><?php  _e('/yyyy/mm/your-uploaded-file-name.jpg','me_dvfa_locale'); ?>' /><br /><p class='help'><?php  _e('Location of the uploaded file.',"me_dvfa_locale"); ?></p></td>
		</tr>
	</tbody>
	</table>
</div>
</div>

<p class="submit"><input type="submit" name="save" id="save" class="button-primary" value="<?php  _e('Save Default Values','me_dvfa_locale'); ?>"  /></p><input type="hidden" name="post_nonce" id="post_id" value="<?php echo $nonce; ?>" />
</form>
</div>
<?php
}

/**
 * This is where the magic happens. We intercept the media inputs before saving 
 * to the database, and insert our defaults if they were left blank
 * 
 * @param array $post
 * @param array $attachment
 * @return array 
 */

function me_dfva_media_attachment_fields_to_save($post, $attachment) {
    
    $title = 'me_dvfa_default_attachment_title';
    $caption = 'me_dvfa_default_attachment_caption';
    $description = 'me_dvfa_default_attachment_description';
    $alttext = 'me_dvfa_default_attachment_alt_text';
    
    // Grab defaults from the DB
    $title_val = get_option($title);
    $caption_val = get_option($caption);
    $description_val = get_option($description);
    $alttext_val = get_option($alttext);	
        
        // this plugin only treats images so far. With a little more testing we'll introduce other mime/types in the future.
        if ( substr($post['post_mime_type'], 0, 5) == 'image' ) {
                // if the user hasn't input any post_title and we don't have a default value on the DB, use system defaults
		if ( strlen(trim($post['post_title'])) == 0 && !$title_val ) {
                    $post['post_title'] = preg_replace('/\.\w+$/', '', basename($post['guid']));
                    $post['errors']['post_title']['errors'][] = __('Empty Title filled from filename.',"me_dvfa_locale");
		} 
                // if the user hasn't input any post_title but we do have a default value on the DB, use user defaults
                elseif ( strlen(trim($post['post_title'])) == 0 && $title_val ) {
                    $post['post_title'] = $title_val;
                }
                
                // if the user hasn't input a caption
                if ( strlen(trim($post['post_excerpt'])) == 0 ) {
                    $post['post_excerpt'] = $caption_val;
                }
                
                // if the user hasn't input a description
                if ( strlen(trim($post['post_content'])) == 0 ) {
                    $post['post_content'] = $description_val;
                    
                }
                
        }
	return array($post, $attachment);
}

add_filter('attachment_fields_to_save', 'me_dfva_media_attachment_fields_to_save', 10, 2);


?>
